@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2012-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2012-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of HyperKitty.
 #
@@ -50,10 +50,10 @@ class AddTagForm(forms.Form):
     tag = forms.CharField(
         label='', help_text=None,
         widget=TextInputWithButton(
-            attrs={'placeholder': 'Add a tag...',
+            attrs={'placeholder': _('Add a tag...'),
                    'class': 'input-medium form-control',
-                   'button_text': 'Add',
-                   'title': 'use commas to add multiple tags',
+                   'button_text': _('Add'),
+                   'title': _('use commas to add multiple tags'),
                    }
             )
         )
