@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2011-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2011-2023 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -38,6 +38,7 @@ from django.core.management import call_command
 from django.core.management.base import BaseCommand, CommandError
 from django.db import Error as DatabaseError
 from django.db import transaction
+from django.utils.formats import date_format
 from django.utils.timezone import utc
 
 from dateutil import tz
@@ -48,7 +49,7 @@ from hyperkitty.lib.incoming import DuplicateMessage, add_to_list
 from hyperkitty.lib.mailman import sync_with_mailman
 from hyperkitty.lib.utils import get_message_id
 from hyperkitty.management.utils import setup_logging
-from hyperkitty.models import Email, Thread
+from hyperkitty.models import Email, MailingList, Thread
 
 
 # Allow all wierd line endings.
@@ -130,16 +131,38 @@ class DbImporter(object):
     def _get_date(self, message, header, report_name):
         try:
             date = message.get(header)
-        except (TypeError, ValueError) as e:
+            if date and not date.datetime:
+                if self.verbose:
+                    self.stderr.write(
+                        "Bad datetime in {} header in message {}{}.".format(
+                            header, unquote(message.get("message-id", 'n/a')),
+                            report_name))
+                return None
+        except (AttributeError, TypeError, ValueError) as e:
             if self.verbose:
                 self.stderr.write(
                     "Can't get {} header in message {}{}: {}.".format(
                         header, unquote(message.get("message-id", 'n/a')),
                         report_name, e))
             return None
-
         return date
 
+    def _fix_mid(self, mid):
+        # Message-IDs of the form
+        # Message-ID: <58C6B8A302CF0E71@example.com> (added by
+        #  postmaster@example.com)
+        # have been seen.  First remove whitespace. Then if the Message-ID
+        # starts with '<' remove everything after the first '>'. Then ensure
+        # it has '<' and '>' at beginning and end.
+        mid = re.sub(r'\s', '', mid)
+        if mid.startswith('<'):
+            mid = re.sub('>.*', '>', mid)
+        else:
+            mid = '<' + mid
+        if not mid.endswith('>'):
+            mid += '>'
+        return mid
+
     def from_mbox(self, mbfile, report_name):
         """
         Insert all the emails contained in an mbox file into the database.
@@ -198,10 +221,15 @@ class DbImporter(object):
                 message.set_unixfrom(unixfrom)
             if message['message-id'] is None:
                 message['Message-ID'] = make_msgid('generated')
+            if message['message-id'].strip() == '':
+                message.replace_header('Message-ID', make_msgid('generated'))
+            if message['message-id'] != self._fix_mid(message['message-id']):
+                message.replace_header(
+                    'Message-ID', self._fix_mid(message['message-id']))
             # Now insert the message
             try:
                 with transaction.atomic():
-                    add_to_list(self.list_address, message)
+                    add_to_list(self.list_address, message, from_import=True)
             except DuplicateMessage as e:
                 if self.verbose:
                     self.stderr.write(
@@ -319,6 +347,11 @@ class Command(BaseCommand):
         # if (settings.DATABASES["default"]["ENGINE"]
         #     != "django.db.backends.sqlite3":
         #     transaction.set_autocommit(False)
+        # Sync list settings with Mailman before importing messages:
+        if not options["no_sync_mailman"]:
+            mlist = MailingList.objects.get_or_create(name=list_address)[0]
+            mlist.update_from_mailman()
+            mlist.save()
         settings.HYPERKITTY_BATCH_MODE = True
         # Only import emails newer than the latest email in the DB
         latest_email_date = Email.objects.filter(
@@ -326,6 +359,10 @@ class Command(BaseCommand):
             ).values("date").order_by("-date").first()
         if latest_email_date and not options["since"]:
             options["since"] = latest_email_date["date"]
+            self.stdout.write(
+                'Warning: not importing messages older than {}. '
+                'Use "--since=<date>" to import older messages.'.format(
+                    date_format(latest_email_date["date"])))
         if options["since"] and options["verbosity"] >= 2:
             self.stdout.write(
                 "Only emails after %s will be imported" % options["since"])
