@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2012-2019 by the Free Software Foundation, Inc.
+# Copyright (C) 2012-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of HyperKitty.
 #
@@ -28,13 +28,14 @@ import os
 import shutil
 from email import message_from_bytes, policy
 from email.message import EmailMessage
+from unittest.mock import Mock
 
 from django.contrib.auth.models import User
 from django.core.cache import cache
+from django.test import override_settings
 
 from bs4 import BeautifulSoup
 from django_mailman3.tests.utils import FakeMMList, FakeMMMember
-from mock import Mock
 
 from hyperkitty.lib.incoming import add_to_list
 from hyperkitty.models import (
@@ -211,6 +212,15 @@ class ExportMboxTestCase(TestCase):
         content = email.get_payload()[0]
         self.assertEqual(content.get_payload(), "Dummy message\n")
 
+    @override_settings(HYPERKITTY_MBOX_EXPORT=False)
+    def test_basic_with_export_disabled(self):
+        url = reverse(
+            "hk_list_export_mbox", args=["list@example.com", "dummy"])
+        response = self.client.get(url)
+        self.assertEqual(response.status_code, 400)
+        self.assertEqual(response.content.decode(),
+                         "Archive download disabled.")
+
     def test_with_sender_name(self):
         email = Email.objects.get(message_id="msg")
         email.sender_name = "Dummy Sender"
@@ -250,6 +260,19 @@ class ExportMboxTestCase(TestCase):
         self.assertEqual(
             [m["Message-ID"] for m in mbox], ["<msg>", "<msg2>"])
 
+    def test_mangle_from_in_serialized_message(self):
+        msg = EmailMessage()
+        msg["From"] = "dummy@example.com"
+        msg["Message-ID"] = "<msg2>"
+        msg["In-Reply-To"] = "<msg>"
+        msg.set_payload("Dummy message\nFrom the sender of this message.")
+        add_to_list("list@example.com", msg)
+        thread_id = Email.objects.get(message_id="msg").thread.thread_id
+        mbox = self._get_mbox(qs="thread=%s" % thread_id)
+        self.assertEqual(len(mbox), 2)
+        self.assertEqual(
+            [m["Message-ID"] for m in mbox], ["<msg>", "<msg2>"])
+
     def test_message(self):
         msg = EmailMessage()
         msg["From"] = "dummy@example.com"
@@ -369,8 +392,8 @@ class MonthsListTestCase(TestCase):
 
     def _assertNotCollapsed(self, panel):
         self.assertTrue(
-            "in" in panel["class"],
-            "Panel %s has no 'in' class" % panel["id"])
+            "show" in panel["class"],
+            "Panel %s has no 'show' class" % panel["id"])
 
     def _assertActivePanel(self, html, panel_num):
         """ Checks that the <panel_num> year is active.
