@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2012-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2012-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of HyperKitty.
 #
@@ -25,13 +25,13 @@ import json
 import re
 import urllib
 from email.message import EmailMessage
+from unittest.mock import patch
 
 from django.contrib.auth.models import User
 from django.test import override_settings
 
 from bs4 import BeautifulSoup
 from django_mailman3.tests.utils import get_flash_messages
-from mock import patch
 
 from hyperkitty.lib.incoming import add_to_list
 from hyperkitty.models import Email, MailingList, Tag, Tagging, Thread
@@ -280,6 +280,24 @@ class ThreadTestCase(TestCase):
         self.assertTrue("num_comments" in response.context)
         self.assertEqual(response.context["num_comments"], 3)
 
+    def test_noscript(self):
+        self._make_msg("msgid2", {"In-Reply-To": "<msgid>"})
+        self._make_msg("msgid3", {"In-Reply-To": "<msgid2>"})
+        self._make_msg("msgid4", {"In-Reply-To": "<msgid3>"})
+        url = reverse('hk_thread', args=["list@example.com", self.threadid])
+        # Request with a user-agent set so that Code doesn't think you are a
+        # bot.
+        response = self.client.get(url, HTTP_USER_AGENT='requests/hyperkitty')
+        self.assertEqual(response.status_code, 200)
+        # By default, the thread doesn't load the replies.
+        self.assertFalse("replies" in response.context)
+        url = url + '?noscript'
+        response = self.client.get(url)
+        self.assertEqual(response.status_code, 200)
+        # By default, the thread doesn't load the replies.
+        self.assertTrue('replies' in response.context)
+        self.assertEqual(len(response.context.get('replies')), 3)
+
     def test_reply_button(self):
         def check_mailto(link):
             self.assertTrue(link is not None)
@@ -461,3 +479,22 @@ class ThreadTestCase(TestCase):
             self.assertEqual(
                 resp['replies_html'].count(
                     'a class="reply"'), 0)
+
+    def test_download_button(self):
+        msg = EmailMessage()
+        msg["From"] = "Dummy Sender <dummy@example.com>"
+        msg["Subject"] = "Dummy Subject"
+        msg["Date"] = "Mon, 02 Feb 2015 13:00:00 +0300"
+        msg["Message-ID"] = "<msgid2>"
+        msg["In-Reply-To"] = "<msgid>"
+        msg.set_payload("Email message.")
+        add_to_list("list@example.com", msg)
+        url = reverse('hk_thread', args=["list@example.com", self.threadid])
+        response = self.client.get(url)
+        self.assertIn(
+            'This thread in gzipped mbox format', response.content.decode())
+        # With the settings set to False, the Download button should be gone.
+        with override_settings(HYPERKITTY_MBOX_EXPORT=False):
+            response = self.client.get(url)
+            self.assertFalse('This thread in gzipped mbox format' in
+                             response.content.decode())
